@@ -20,6 +20,16 @@
        * @type {!Object.<number, function(?Object)>}
        */
       this._callbacks = {};
+
+      /**
+       * @type {!Array.<!ExtensionDescriptor>}
+       */
+      this._pendingExtensionDescriptors = [];
+
+      /**
+       * @type {?function(!ExtensionDescriptor)}
+       */
+      this._addExtensionCallback = null;
     }
 
     /**
@@ -29,8 +39,9 @@
     embedderMessageAck(id, arg) {
       const callback = this._callbacks[id];
       delete this._callbacks[id];
-      if (callback)
+      if (callback) {
         callback(arg);
+      }
     }
 
     /**
@@ -40,11 +51,13 @@
      */
     sendMessageToEmbedder(method, args, callback) {
       const callId = ++this._lastCallId;
-      if (callback)
+      if (callback) {
         this._callbacks[callId] = callback;
+      }
       const message = {'id': callId, 'method': method};
-      if (args.length)
+      if (args.length) {
         message.params = args;
+      }
       DevToolsHost.sendMessageToEmbedder(JSON.stringify(message));
     }
 
@@ -66,11 +79,15 @@
       // Support for legacy front-ends (<M41).
       if (window['WebInspector'] && window['WebInspector']['addExtensions']) {
         window['WebInspector']['addExtensions'](extensions);
-      } else if (window['InspectorFrontendAPI']) {
+      } else {
         // The addExtensions command is sent as the onload event happens for
-        // DevTools front-end. In case of hosted mode, this
-        // happens before the InspectorFrontendAPI is initialized.
-        this._dispatchOnInspectorFrontendAPI('addExtensions', [extensions]);
+        // DevTools front-end. We should buffer this command until the frontend
+        // is ready for it.
+        if (this._addExtensionCallback) {
+          extensions.forEach(this._addExtensionCallback);
+        } else {
+          this._pendingExtensionDescriptors.pushAll(extensions);
+        }
       }
     }
 
@@ -225,6 +242,21 @@
       this._dispatchOnInspectorFrontendAPI('keyEventUnhandled', [event]);
     }
 
+    /**
+     * @param {function(!ExtensionDescriptor)} callback
+     */
+    setAddExtensionCallback(callback) {
+      this._addExtensionCallback = callback;
+      if (this._pendingExtensionDescriptors.length) {
+        this._pendingExtensionDescriptors.forEach(this._addExtensionCallback);
+        this._pendingExtensionDescriptors = [];
+      }
+    }
+
+    reattachMainTarget() {
+      this._dispatchOnInspectorFrontendAPI('reattachMainTarget', []);
+    }
+
     /**
      * @param {boolean} hard
      */
@@ -262,11 +294,21 @@
      * @param {string} tabId
      */
     setInspectedTabId(tabId) {
+      this._inspectedTabIdValue = tabId;
+
       // Support for legacy front-ends (<M41).
-      if (window['WebInspector'] && window['WebInspector']['setInspectedTabId'])
+      if (window['WebInspector'] && window['WebInspector']['setInspectedTabId']) {
         window['WebInspector']['setInspectedTabId'](tabId);
-      else
+      } else {
         this._dispatchOnInspectorFrontendAPI('setInspectedTabId', [tabId]);
+      }
+    }
+
+    /**
+     * @return {string|undefined}
+     */
+    getInspectedTabId() {
+      return this._inspectedTabIdValue;
     }
 
     /**
@@ -363,8 +405,9 @@
       // Support for legacy (<57) frontends.
       if (window.Runtime && window.Runtime.queryParam) {
         const panelToOpen = window.Runtime.queryParam('panel');
-        if (panelToOpen)
+        if (panelToOpen) {
           window.DevToolsAPI.showPanel(panelToOpen);
+        }
       }
     }
 
@@ -534,8 +577,9 @@
      */
     recordEnumeratedHistogram(actionName, actionCode, bucketSize) {
       // Support for M49 frontend.
-      if (actionName === 'DevTools.DrawerShown')
+      if (actionName === 'DevTools.DrawerShown') {
         return;
+      }
       DevToolsAPI.sendMessageToEmbedder('recordEnumeratedHistogram', [actionName, actionCode, bucketSize], null);
     }
 
@@ -682,6 +726,7 @@
     }
 
     /**
+     * Only needed to run Lighthouse on old devtools.
      * @override
      * @param {function()} callback
      */
@@ -777,6 +822,14 @@
       return DevToolsHost.isHostedMode();
     }
 
+    /**
+     * @override
+     * @param {function(!ExtensionDescriptor)} callback
+     */
+    setAddExtensionCallback(callback) {
+      DevToolsAPI.setAddExtensionCallback(callback);
+    }
+
     // Backward-compatible methods below this line --------------------------------------------
 
     /**
@@ -1041,16 +1094,18 @@
     function objectObserve(object, observer) {
       if (window['WebInspector']) {
         const settingPrototype = /** @type {!Object} */ (window['WebInspector']['Setting']['prototype']);
-        if (typeof settingPrototype['remove'] === 'function')
+        if (typeof settingPrototype['remove'] === 'function') {
           settingPrototype['remove'] = settingRemove;
+        }
       }
       /** @type {!Set<string>} */
       const changedProperties = new Set();
       let scheduled = false;
 
       function scheduleObserver() {
-        if (scheduled)
+        if (scheduled) {
           return;
+        }
         scheduled = true;
         setImmediate(callObserver);
       }
@@ -1096,8 +1151,9 @@
         });
       }
 
-      for (let i = 0; i < properties.length; ++i)
+      for (let i = 0; i < properties.length; ++i) {
         defineProperty(properties[i]);
+      }
     }
 
     window.Object.observe = objectObserve;
@@ -1169,20 +1225,23 @@
    */
   function keyCodeToKeyIdentifier(keyCode) {
     let result = staticKeyIdentifiers.get(keyCode);
-    if (result !== undefined)
+    if (result !== undefined) {
       return result;
+    }
     result = 'U+';
     const hexString = keyCode.toString(16).toUpperCase();
-    for (let i = hexString.length; i < 4; ++i)
+    for (let i = hexString.length; i < 4; ++i) {
       result += '0';
+    }
     result += hexString;
     return result;
   }
 
   function installBackwardsCompatibility() {
     const majorVersion = getRemoteMajorVersion();
-    if (!majorVersion)
+    if (!majorVersion) {
       return;
+    }
 
     /** @type {!Array<string>} */
     const styleRules = [];
@@ -1203,15 +1262,17 @@
 
       const origAdd = DOMTokenList.prototype.add;
       DOMTokenList.prototype.add = function(...tokens) {
-        if (tokens[0].startsWith('insertion-point') || tokens[0].startsWith('tabbed-pane-header'))
+        if (tokens[0].startsWith('insertion-point') || tokens[0].startsWith('tabbed-pane-header')) {
           this._myElement.slot = '.' + tokens[0];
+        }
         return origAdd.apply(this, tokens);
       };
 
       const origCreateElement = Document.prototype.createElement;
       Document.prototype.createElement = function(tagName, ...rest) {
-        if (tagName === 'content')
+        if (tagName === 'content') {
           tagName = 'slot';
+        }
         const element = origCreateElement.call(this, tagName, ...rest);
         element.classList._myElement = element;
         return element;
@@ -1223,31 +1284,33 @@
         }
       });
 
-      // Document.prototype.createElementWithClass is a DevTools method, so we
-      // need to wait for DOMContentLoaded in order to override it.
-      if (window.document.head &&
-          (window.document.readyState === 'complete' || window.document.readyState === 'interactive'))
-        overrideCreateElementWithClass();
-      else
-        window.addEventListener('DOMContentLoaded', overrideCreateElementWithClass);
-
       function overrideCreateElementWithClass() {
         window.removeEventListener('DOMContentLoaded', overrideCreateElementWithClass);
 
         const origCreateElementWithClass = Document.prototype.createElementWithClass;
         Document.prototype.createElementWithClass = function(tagName, className, ...rest) {
-          if (tagName !== 'button' || (className !== 'soft-dropdown' && className !== 'dropdown-button'))
+          if (tagName !== 'button' || (className !== 'soft-dropdown' && className !== 'dropdown-button')) {
             return origCreateElementWithClass.call(this, tagName, className, ...rest);
+          }
           const element = origCreateElementWithClass.call(this, 'div', className, ...rest);
           element.tabIndex = 0;
           element.role = 'button';
           return element;
         };
       }
+
+      // Document.prototype.createElementWithClass is a DevTools method, so we
+      // need to wait for DOMContentLoaded in order to override it.
+      if (window.document.head &&
+          (window.document.readyState === 'complete' || window.document.readyState === 'interactive')) {
+        overrideCreateElementWithClass();
+      } else {
+        window.addEventListener('DOMContentLoaded', overrideCreateElementWithClass);
+      }
     }
 
     // Custom Elements V0 polyfill
-    if (majorVersion <= 73 && !Document.prototype.registerElement) {
+    if (majorVersion <= 73 && !Document.prototype.hasOwnProperty('registerElement')) {
       const fakeRegistry = new Map();
       Document.prototype.registerElement = function(typeExtension, options) {
         const {prototype, extends: localName} = options;
@@ -1256,13 +1319,15 @@
           const element = document.createElement(localName || typeExtension);
           const skip = new Set(['constructor', '__proto__']);
           for (const key of Object.keys(Object.getOwnPropertyDescriptors(prototype.__proto__ || {}))) {
-            if (skip.has(key))
+            if (skip.has(key)) {
               continue;
+            }
             element[key] = prototype[key];
           }
           element.setAttribute('is', typeExtension);
-          if (element['createdCallback'])
+          if (element['createdCallback']) {
             element['createdCallback']();
+          }
           return element;
         };
         fakeRegistry.set(typeExtension, callback);
@@ -1272,8 +1337,9 @@
       const origCreateElement = Document.prototype.createElement;
       Document.prototype.createElement = function(tagName, fakeCustomElementType) {
         const fakeConstructor = fakeRegistry.get(fakeCustomElementType);
-        if (fakeConstructor)
+        if (fakeConstructor) {
           return fakeConstructor();
+        }
         return origCreateElement.call(this, tagName, fakeCustomElementType);
       };
 
@@ -1283,8 +1349,9 @@
       //   classList.toggle('a');
       const originalDOMTokenListToggle = DOMTokenList.prototype.toggle;
       DOMTokenList.prototype.toggle = function(token, force) {
-        if (arguments.length === 1)
+        if (arguments.length === 1) {
           force = !this.contains(token);
+        }
         return originalDOMTokenListToggle.call(this, token, !!force);
       };
     }
@@ -1302,8 +1369,9 @@
          */
         ShadowRoot.prototype.elementFromPoint = function(x, y) {
           const originalResult = ShadowRoot.prototype.__originalShadowRootElementFromPoint.apply(this, arguments);
-          if (this.host && originalResult === this.host)
+          if (this.host && originalResult === this.host) {
             return null;
+          }
           return originalResult;
         };
       }
@@ -1321,8 +1389,9 @@
       });
     }
 
-    if (majorVersion <= 50)
+    if (majorVersion <= 50) {
       installObjectObserve();
+    }
 
     if (majorVersion <= 45) {
       /**
@@ -1356,8 +1425,9 @@
       window.CSSPrimitiveValue = CSSPrimitiveValue;
     }
 
-    if (majorVersion <= 45)
+    if (majorVersion <= 45) {
       styleRules.push('* { min-width: 0; min-height: 0; }');
+    }
 
     if (majorVersion <= 51) {
       // Support for quirky border-image behavior (<M51), see:
@@ -1371,8 +1441,9 @@
           '.coverage-toolbar-container, .animation-timeline-toolbar-container, .computed-properties { flex-basis: auto; }');
     }
 
-    if (majorVersion <= 50)
+    if (majorVersion <= 50) {
       Event.prototype.deepPath = undefined;
+    }
 
     if (majorVersion <= 54) {
       window.FileError = /** @type {!function (new: FileError) : ?} */ ({
@@ -1392,8 +1463,9 @@
   function getRemoteMajorVersion() {
     try {
       const remoteVersion = new URLSearchParams(window.location.search).get('remoteVersion');
-      if (!remoteVersion)
+      if (!remoteVersion) {
         return null;
+      }
       const majorVersion = parseInt(remoteVersion.split('.')[0], 10);
       return majorVersion;
     } catch (e) {
@@ -1405,8 +1477,9 @@
    * @param {!Array<string>} styleRules
    */
   function installExtraStyleRules(styleRules) {
-    if (!styleRules.length)
+    if (!styleRules.length) {
       return;
+    }
     const styleText = styleRules.join('\n');
     document.head.appendChild(createStyleElement(styleText));
 
@@ -1424,7 +1497,6 @@
    */
   function createStyleElement(styleText) {
     const style = document.createElement('style');
-    style.type = 'text/css';
     style.textContent = styleText;
     return style;
   }
